Index: kernel/generic/src/udebug/udebug_ops.c
===================================================================
--- kernel/generic/src/udebug/udebug_ops.c	(revision 63e27efdf2fe6d3fa02bbb5ee1da00df5cc07e9d)
+++ kernel/generic/src/udebug/udebug_ops.c	(revision 001667409fe983adba70256d5d79278a7e0e12bd)
@@ -167,5 +167,5 @@
  * @param call The BEGIN call we are servicing.
  *
  * @return 0 (OK, but not done yet), 1 (done) or negative error code.
  *
  */
@@ -184,13 +184,4 @@
 	TASK->udebug.begin_call = call;
 	TASK->udebug.debugger = call->sender;
-	
-	int reply;
-	
-	if (TASK->udebug.not_stoppable_count == 0) {
-		TASK->udebug.dt_state = UDEBUG_TS_ACTIVE;
-		TASK->udebug.begin_call = NULL;
-		reply = 1;  /* immediate reply */
-	} else
-		reply = 0;  /* no reply */
 	
 	/* Set udebug.active on all of the task's userspace threads. */
@@ -207,5 +198,5 @@
 	
 	mutex_unlock(&TASK->udebug.lock);
-	return reply;
+	return EOK;
 }
 
@@ -167,5 +167,5 @@
  * @param call The BEGIN call we are servicing.
  *
- * @return 0 (OK, but not done yet), 1 (done) or negative error code.
+ * @return EOK or negative error code.
  *
  */
